* PLEASE, INCLUDE THE FOLLOWING LINES AT THE BEGINNING OF THE DO FILE.
* THE FIRST ONE ALLOWS TO PAUSE THE DO FILE WHENEVER IS REQUIRED
* ADDITIONALLY YOU YOUR CHANGE "CLEAR" BY "CLEAR ALL" TO CLEAN THE STATA MEMORY
* NOW THAT WE HAVE INTRODUCED MATRICES


pause on
clear all

* THEN, AS BEFORE.....
* LOOK FROM THE FOLLOWING SECTION AND REPLACE FROM HERE (31/08/2011)

******************************************************************************************************************************

* PLEASE CHECK THE PREVIOUS LINES.  CHECK THE NUMBER OF MISSING VALUES PER VARIABLE 
* AND THE TOTAL NUMBER OF MISSING VALUES. IDENTIFY THE CAUSE OF MAJORITY OF THE MISSING VALUES 
* AND WRITE ITS NAME IN THE FOLLOWING LINE


pause
local m="d_childwor_miss"

***********************************************************************
***** Create de identification vector (poor/non poor) *****************
***** and compute individual average of deprivation *******************
***********************************************************************

* WE CALCULATE THE NATIONAL MPI USING THE WEIGHTS AND THE WEIGHTED CENSORED MATRIX REPRESENTED BY (CI*IDENTIFICATION).

egen total_w=total(weight) if missing==0

forvalues x=1(1)10 {
gen ch_`x'0p=(ci>=`x'/10) 
replace ch_`x'0p=. if missing==1
gen a_`x'0p=(ci) if ch_`x'0p==1
replace a_`x'0p=. if missing==1
egen MPI_`x'0p= total(ci*ch_`x'0p*weight/total_w)
label var ch_`x'0p "Condition of Multidimensional Poverty  k=`x'"
label var a_`x'0p "Individual Average deprivation  k=`x'"
label var MPI_`x'0p "National Multidimensional Poverty Index k=`x'"
}

summarize ch_* a_* MPI_* [aw=weight]

************************************************************************
******* Compute raw headcounts        **********************************
************************************************************************

foreach var in `varlist_pov' {
gen `var'_raw=(`var')
replace `var'_raw=. if missing==1
}

su *_raw  [iw=weight]

***********************************************************************************
*********** Compute Censored headcount and censored headocunt ******
***********************************************************************************
* PLEASE DEFINE IN THE FIRST LINE YOUR POVERTY CUTOFF, THE EXAMPLE SHOWS K=20 IS 20%
* IN THE SECOND LINE REPLACE WITH THE NAME OF THE CATEGORICAL VARIABLE
* THAT REPRESENTS THE DIFFERENT SUBGROUPS. (E.G. REPLACE "NATIONAL" -->> "REGION" 
* IF YOU REQUIRE RESULTS DECOMPOSED BY REGION)...

pause

gen national=1
local k=20
local r="national"

foreach var in `varlist_pov' {
gen `var'_CH_`k'=(`var'==1 & ch_`k'==1)
replace `var'_CH_`k'=. if missing==1
}

summarize *_CH_`k' [iw=weight]

*****************************************************************************************
**** Sampling ***************************************************************************
**** Define decomposition rule (region, area, sex, etc)
**** We keep the information of the weighted population before reducing the sample to only 
**** those cases with information in all the indicators considered


egen total_b = total(weight)
label var total_b "Total Population Before Sample Drop"
egen pop_shr_before = total(weight/total_b), by(`r')
label var pop_shr_before "Weighted Population Share of Each `r' before Sample Reduction"
gen temp=1 // We generate this variable for counting observations
egen sample_r_before = total(temp), by(`r')
label var sample_r_before "Sample Size of each `r' before Sample Reduction"

egen pop_shr_after = total(weight/total_w) if miss==0, by(`r')
label var pop_shr_after "Weighted Population Share of Each `r' after Sample Reduction"
egen sample_r_after = total(temp) if missing==0, by(`r')
label var sample_r_after  "Sample Size of Each `r' after Sample Reduction"
gen sample_lost_ratio= sample_r_after/sample_r_before
label var sample_lost_ratio  "Relative size of the final sample after reduction in each `r'"

************************************************************************************
** Calculating the confidence intervals of the M0 estimated ************************

* DEFINE THE CLUSTER AND STRATA FROM THE SURVEY
* CREATE THE APPROPRIATE 'PSU' AND 'STATA' VARIABLE CONSULTING THE MANUAL OF THE SURVEY. 
* CONSTRUCT PSU AND STRATA AS NECESSARY

pause 

** Declare survey design for dataset **********************
svyset PSU [pweight=weight], strata(strata)


*** Bias Analysis *****************************************

svy: mean urban, over(`m')
cap test [urban]0 = [urban]1

foreach var in urban `varlist_pov' {
svy: mean `var', over(`m')
cap test [`var']0 = [`var']1
}

*check the previous results to analize possible bias in missing values

pause
************************************************************

** National Level

** Calculating confidence intervals for M0
gen Adj_H_`k'p=ci*ch_`k'p
svy: mean Adj_H_`k'p
gen lb_MPI_`k'p=_b[Adj_H_`k'p]-1.95996*((_se[Adj_H_`k'p]))
gen hb_MPI_`k'p=_b[Adj_H_`k'p]+1.95996*((_se[Adj_H_`k'p]))

*Regional level

** Identify the number of region

capture tab `r'
local nr=r(r)
gen lb_M0_`k'p=.
gen hb_M0_`k'p=.
gen lb_sH_`k'p=.
gen hb_sH_`k'p=.
gen lb_sA_`k'p=.
gen hb_sA_`k'p=.
foreach var in `varlist_pov' {
gen lb_s`var'_`k'p=.
gen hb_s`var'_`k'p=.
}


forvalue g=1(1)`nr' {

** Calculating confidence intervals for M0
svy: mean Adj_H_`k'p if `r'==`g'
replace lb_M0_`k'p=_b[Adj_H_`k'p]-1.95996*((_se[Adj_H_`k'p]))  if `r'==`g'
replace hb_M0_`k'p=_b[Adj_H_`k'p]+1.95996*((_se[Adj_H_`k'p]))  if `r'==`g'
** Calculating confidence intervals for H
svy: mean  ch_`k'p  if `r'==`g'
replace lb_sH_`k'p=_b[ch_`k'p]-1.95996*((_se[ch_`k'p]))  if `r'==`g'
replace hb_sH_`k'p=_b[ch_`k'p]+1.95996*((_se[ch_`k'p]))  if `r'==`g'
** Calculating confidence intervals for A
svy: mean  ch_`k'p Adj_H_`k'p  if `r'==`g'
mat cov= e(V)
local cov = cov[2,1]
replace lb_sA_`k'p=(_b[Adj_H_`k'p]/_b[ch_`k'p])-2*((_se[Adj_H_`k'p]^2/_b[ch_`k'p]^2)+((_b[Adj_H_`k'p]/(_b[ch_`k'p])^2)^2)*(_se[ch_`k'p]^2)-2*`cov')^0.5  if `r'==`g'
replace hb_sA_`k'p=(_b[Adj_H_`k'p]/_b[ch_`k'p])+2*((_se[Adj_H_`k'p]^2/_b[ch_`k'p]^2)+((_b[Adj_H_`k'p]/(_b[ch_`k'p])^2)^2)*(_se[ch_`k'p]^2)-2*`cov')^0.5  if `r'==`g'
** Calculating confidence intervals for Censored Headcount
foreach var in `varlist_pov' {
svy: mean  `var'_CH_`k'  if `r'==`g'
replace lb_s`var'_`k'p=_b[`var'_CH_`k']-1.95996*((_se[`var'_CH_`k']))  if `r'==`g'
replace hb_s`var'_`k'p=_b[`var'_CH_`k']+1.95996*((_se[`var'_CH_`k'])) if `r'==`g'
}
}
************************************************************************************
**** Collapsing ********************************************************************
* So far, our database has individual level data, if we want to aggregate
* at any level, we use the command collapse. Collapse calculates weighted 
* averages at the  level defined by the user (region), if the option "by(region)"
* is not specified, the observations are aggregated at the national level.
* Before collapse, save your results using the following command
*************************************************************************************

save data, replace

* You can use also the commands preserve before the command collapse and restore just after
* preserve

* The following command will "collapse" our individual results according to the subgroup previously defined. 
pause
collapse ch_* a_* *_CH_`k' *_raw *_miss missing MPI_* pop_shr* sample_r_* sample_lost_ratio lb_* hb_*  [iw=weight],by(`r')

* You have already calculated the national MPI. With the following lines you will calculate the 
* MPI for every region using the formulation MPI=H*A obtained after collapsing the dataset.
* additionally, since with "collapse" average per region were obtained, 
* we rename the Condition of Multidimensional Poverty for Decomposed Multidimensional Headcount Ratio
* and Individual Average Deprivation for Decomposed Average Deprivation

forvalues x=1(1)10 {
gen M0_`x'0p=ch_`x'0p*a_`x'0p
label var M0_`x'0p "Population Subgroup Multidimensional Poverty Index k=`x'0%"
ren ch_`x'0p H_`x'0p
label var H_`x'0p "Population Subgroup Multidimensional Headcount Ratio k=`x'0%"
ren a_`x'0p A_`x'0p
label var A_`x'0p "Population Subgroup Average Deprivation k=`x'0%"
label var MPI_`x'0p "National Multidimensional Poverty k=`x'0%"
}

* You can now obtain the contribution of each dimension/indicator using the censored headcount ratio per region.

foreach var in `varlist_pov'{
gen `var'_cont=((`var'_CH_`k'* `w_`var'')/ M0_`k'p)
label var `var'_cont "Population Subgroup Contribution of `var' to the total Poverty k=`k'%"
label var `var'_CH_`k' "Population Subgroup Censored Headcount `var' k=`k'%"

label var `var'_raw "Population Subgroup Raw Headcount `var'"
label var `var'_miss "Population Subgroup Missing values `var'"
}

label var lb_MPI_`k'p "Lower Boundary Adj_H_`k'% (MPI)"
label var hb_MPI_`k'p "Higher Boundary Adj_H_`k'% (MPI)"

label var lb_sA_`k'p "Lower Boundary Subgroup A_`k'% "
label var hb_sA_`k'p "Higher Boundary Subgroup A_`k'% "

label var lb_sH_`k'p "Lower Boundary  Subgroup H`k'%"
label var hb_sH_`k'p "Higher Boundary Subgroup H `k'%"

label var lb_M0_`k'p "Lower Boundary Subgroup Adj_H_`k'% (MPI)"
label var hb_M0_`k'p "Higher Boundary Subgroup Adj_H_`k'% (MPI)"

gen cont_subgroup_`k'=M0_`k'p/MPI_`k'p*pop_shr_after
label variable cont_subgroup_`k' "Population Subgroup Contribution"

save results, replace

log close
*restore









